@@ -1,7 +1,7 @@
 #
 # remt - reMarkable tablet command-line tools
 #
-# Copyright (C) 2018-2019 by Artur Wroblewski <wrobell@riseup.net>
+# Copyright (C) 2018-2020 by Artur Wroblewski <wrobell@riseup.net>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,16 +23,13 @@ Command line commands.
 
 import asyncssh
 import configparser
-import glob
 import json
-import operator
 import os.path
 import shutil
 import urllib.request
 from contextlib import asynccontextmanager
 from collections import namedtuple
-from cytoolz.dicttoolz import assoc, get_in
-from cytoolz.functoolz import compose
+from cytoolz.dicttoolz import get_in
 from datetime import datetime
 from iterfzf import iterfzf
 from tempfile import TemporaryDirectory
@@ -41,12 +38,10 @@ from uuid import uuid4 as uuid
 import remt
 from .error import *
 from .indexer import ann_text, fmt_ann_text
+from .meta import BASE_DIR, fn_path, read_meta, fn_metadata
 from .pdf import pdf_open
 from .util import flatten
 
-
-BASE_DIR = '/home/root/.local/share/remarkable/xochitl'
-
 FILE_TYPE = {
     'CollectionType': 'd',
 }
@@ -124,15 +119,6 @@ async def remt_ctx():
         else:
             raise
 
-def fn_path(data, base=BASE_DIR, ext='.*'):
-    """
-    Having metadata object create UUID based path of a file created by
-    reMarkable tablet.
-
-    :param data: Metadata object.
-    """
-    return '{}/{}{}'.format(base, data['uuid'], ext)
-
 def norm_path(path):
     """
     Normalise path of a file on a reMarkable tablet.
@@ -144,19 +130,6 @@ def norm_path(path):
     """
     return os.path.normpath(path).strip('/')
 
-def fn_metadata(meta, path):
-    """
-    Get reMarkable tablet file metadata or raise file not found error if no
-    metadata for path is found.
-
-    :param meta: reMarkable tablet metadata.
-    :param path: Path of reMarkable tablet file.
-    """
-    data = meta.get(path)
-    if not data:
-        raise FileError('File or directory not found: {}'.format(path))
-    return data
-
 def fn_interactive(ctx: RemtContext, is_dir: bool=False) -> str:
     """
     Get filename interactively using `fzf` program.
@@ -212,69 +185,6 @@ def parse_page(fin, page_number):
     else:
         yield from remt.empty_page(page_number)
 
-#
-# metadata
-#
-
-def to_path(data, meta):
-    parent = data.get('parent')
-    name = data['visibleName']
-    if parent:
-        return to_path(meta[parent], meta) + '/' + name
-    else:
-        return name
-
-def resolve_uuid(meta):
-    meta = {k: assoc(v, 'uuid', k) for k, v in meta.items()}
-    return {to_path(data, meta): data for data in meta.values()}
-
-def create_metadata(is_dir, parent_uuid, name):
-    now = datetime.utcnow()
-    tstamp = int(now.timestamp() * 1000)
-    type = 'CollectionType' if is_dir else 'DocumentType'
-    data = {
-        'deleted': False,
-        'lastModified': str(tstamp),
-        'metadatamodified': True,
-        'modified': True,
-        'parent': parent_uuid,
-        'pinned': False,
-        'synced': False,
-        'type': type,
-        'version': 0,
-        'visibleName': name,
-    }
-    return data
-
-async def read_meta(sftp, dir_meta):
-    """
-    Read metadata from a reMarkable tablet.
-    """
-    await sftp.mget(BASE_DIR + '/*.metadata', dir_meta)
-    await sftp.mget(BASE_DIR + '/*.content', dir_meta)
-
-    to_uuid = compose(
-        operator.itemgetter(0),
-        os.path.splitext,
-        os.path.basename,
-    )
-    load_json = compose(json.load, open)
-
-    files_content = glob.glob(dir_meta + '/*.content')
-    files_content = {to_uuid(fn): fn for fn in files_content}
-
-    files = glob.glob(dir_meta + '/*.metadata')
-    files = ((fn, to_uuid(fn)) for fn in files)
-    files = ((fn, u) for fn, u in files if u in files_content)
-
-    # load metadata file and content file
-    data = (
-        (u, load_json(fn), load_json(files_content[u]))
-        for fn, u in files
-    )
-    meta = {u: assoc(m, 'content', c) for u, m, c in data}
-    return resolve_uuid(meta)
-
 #
 # cmd: ls
 #
